# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: diagnostic.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'diagnostic.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import device_info_pb2 as device__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64iagnostic.proto\x12\ndiagnostic\x1a\x11\x64\x65vice_info.proto\"\x93\x04\n\x08\x43ounters\x12\'\n\x1fhawkbit_status_connection_error\x18\x01 \x01(\r\x12,\n hawkbit_status_unconfirmed_image\x18\x02 \x01(\rB\x02\x18\x01\x12)\n\x1dhawkbit_status_metadata_error\x18\x03 \x01(\rB\x02\x18\x01\x12%\n\x1dhawkbit_status_download_error\x18\x04 \x01(\r\x12*\n\x1ehawkbit_status_already_updated\x18\x05 \x01(\rB\x02\x18\x01\x12(\n hawkbit_status_update_downloaded\x18\x06 \x01(\r\x12 \n\x18hawkbit_status_no_update\x18\x07 \x01(\r\x12(\n\x1chawkbit_status_cancel_update\x18\x08 \x01(\rB\x02\x18\x01\x12,\n hawkbit_status_probe_in_progress\x18\t \x01(\rB\x02\x18\x01\x12$\n\x1ctimeout_internet_unreachable\x18\n \x01(\r\x12\"\n\x1atimeout_hawkbit_connection\x18\x0b \x01(\r\x12#\n\x1bhan_msg_successfully_parsed\x18\x0c \x01(\r\x12\x1f\n\x17han_msg_buffer_overflow\x18\r \x01(\r\"\xb0\x01\n\nDiagnostic\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.diagnostic.EventType\x12\x10\n\x08uptime_s\x18\x02 \x01(\x04\x12\x15\n\rwifi_rssi_dbm\x18\x03 \x01(\x05\x12,\n\x0b\x64\x65vice_info\x18\x04 \x01(\x0b\x32\x17.device_info.DeviceInfo\x12&\n\x08\x63ounters\x18\x05 \x01(\x0b\x32\x14.diagnostic.Counters*\x9b\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45VENT_TYPE_TIMER\x10\x01\x12%\n!EVENT_TYPE_PROVISIONING_REQUESTED\x10\x02\x12\x1d\n\x19\x45VENT_TYPE_MQTT_CONNECTED\x10\x03\x12\x1f\n\x1b\x45VENT_TYPE_REBOOT_REQUESTED\x10\x04\x12\x1b\n\x17\x45VENT_TYPE_BOOT_UNKNOWN\x10\x05\x12\x1c\n\x18\x45VENT_TYPE_BOOT_SOFTWARE\x10\x06\x12\x1c\n\x18\x45VENT_TYPE_BOOT_POWER_ON\x10\x07\x12\x1c\n\x18\x45VENT_TYPE_BOOT_WATCHDOG\x10\x08\x42;\n7io.bitvis.power.interfaces.powerhub.diagnostic.protobufP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'diagnostic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.bitvis.power.interfaces.powerhub.diagnostic.protobufP\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_unconfirmed_image']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_unconfirmed_image']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_metadata_error']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_metadata_error']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_already_updated']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_already_updated']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_cancel_update']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_cancel_update']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_probe_in_progress']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_probe_in_progress']._serialized_options = b'\030\001'
  _globals['_EVENTTYPE']._serialized_start=765
  _globals['_EVENTTYPE']._serialized_end=1048
  _globals['_COUNTERS']._serialized_start=52
  _globals['_COUNTERS']._serialized_end=583
  _globals['_DIAGNOSTIC']._serialized_start=586
  _globals['_DIAGNOSTIC']._serialized_end=762
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceInfo(_message.Message):
    __slots__ = ("mac_address", "model_name", "sw_version", "hw_revision")
    MAC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    SW_VERSION_FIELD_NUMBER: _ClassVar[int]
    HW_REVISION_FIELD_NUMBER: _ClassVar[int]
    mac_address: bytes
    model_name: str
    sw_version: str
    hw_revision: int
    def __init__(self, mac_address: _Optional[bytes] = ..., model_name: _Optional[str] = ..., sw_version: _Optional[str] = ..., hw_revision: _Optional[int] = ...) -> None: ...



import device_info_pb2 as _device_info_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TYPE_UNSPECIFIED: _ClassVar[EventType]
    EVENT_TYPE_TIMER: _ClassVar[EventType]
    EVENT_TYPE_PROVISIONING_REQUESTED: _ClassVar[EventType]
    EVENT_TYPE_MQTT_CONNECTED: _ClassVar[EventType]
    EVENT_TYPE_REBOOT_REQUESTED: _ClassVar[EventType]
    EVENT_TYPE_BOOT_UNKNOWN: _ClassVar[EventType]
    EVENT_TYPE_BOOT_SOFTWARE: _ClassVar[EventType]
    EVENT_TYPE_BOOT_POWER_ON: _ClassVar[EventType]
    EVENT_TYPE_BOOT_WATCHDOG: _ClassVar[EventType]
EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_TIMER: EventType
EVENT_TYPE_PROVISIONING_REQUESTED: EventType
EVENT_TYPE_MQTT_CONNECTED: EventType
EVENT_TYPE_REBOOT_REQUESTED: EventType
EVENT_TYPE_BOOT_UNKNOWN: EventType
EVENT_TYPE_BOOT_SOFTWARE: EventType
EVENT_TYPE_BOOT_POWER_ON: EventType
EVENT_TYPE_BOOT_WATCHDOG: EventType

class Counters(_message.Message):
    __slots__ = ("hawkbit_status_connection_error", "hawkbit_status_unconfirmed_image", "hawkbit_status_metadata_error", "hawkbit_status_download_error", "hawkbit_status_already_updated", "hawkbit_status_update_downloaded", "hawkbit_status_no_update", "hawkbit_status_cancel_update", "hawkbit_status_probe_in_progress", "timeout_internet_unreachable", "timeout_hawkbit_connection", "han_msg_successfully_parsed", "han_msg_buffer_overflow")
    HAWKBIT_STATUS_CONNECTION_ERROR_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_UNCONFIRMED_IMAGE_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_METADATA_ERROR_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_DOWNLOAD_ERROR_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_ALREADY_UPDATED_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_UPDATE_DOWNLOADED_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_NO_UPDATE_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_CANCEL_UPDATE_FIELD_NUMBER: _ClassVar[int]
    HAWKBIT_STATUS_PROBE_IN_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_INTERNET_UNREACHABLE_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HAWKBIT_CONNECTION_FIELD_NUMBER: _ClassVar[int]
    HAN_MSG_SUCCESSFULLY_PARSED_FIELD_NUMBER: _ClassVar[int]
    HAN_MSG_BUFFER_OVERFLOW_FIELD_NUMBER: _ClassVar[int]
    hawkbit_status_connection_error: int
    hawkbit_status_unconfirmed_image: int
    hawkbit_status_metadata_error: int
    hawkbit_status_download_error: int
    hawkbit_status_already_updated: int
    hawkbit_status_update_downloaded: int
    hawkbit_status_no_update: int
    hawkbit_status_cancel_update: int
    hawkbit_status_probe_in_progress: int
    timeout_internet_unreachable: int
    timeout_hawkbit_connection: int
    han_msg_successfully_parsed: int
    han_msg_buffer_overflow: int
    def __init__(self, hawkbit_status_connection_error: _Optional[int] = ..., hawkbit_status_unconfirmed_image: _Optional[int] = ..., hawkbit_status_metadata_error: _Optional[int] = ..., hawkbit_status_download_error: _Optional[int] = ..., hawkbit_status_already_updated: _Optional[int] = ..., hawkbit_status_update_downloaded: _Optional[int] = ..., hawkbit_status_no_update: _Optional[int] = ..., hawkbit_status_cancel_update: _Optional[int] = ..., hawkbit_status_probe_in_progress: _Optional[int] = ..., timeout_internet_unreachable: _Optional[int] = ..., timeout_hawkbit_connection: _Optional[int] = ..., han_msg_successfully_parsed: _Optional[int] = ..., han_msg_buffer_overflow: _Optional[int] = ...) -> None: ...

class Diagnostic(_message.Message):
    __slots__ = ("type", "uptime_s", "wifi_rssi_dbm", "device_info", "counters")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UPTIME_S_FIELD_NUMBER: _ClassVar[int]
    WIFI_RSSI_DBM_FIELD_NUMBER: _ClassVar[int]
    DEVICE_INFO_FIELD_NUMBER: _ClassVar[int]
    COUNTERS_FIELD_NUMBER: _ClassVar[int]
    type: EventType
    uptime_s: int
    wifi_rssi_dbm: int
    device_info: _device_info_pb2.DeviceInfo
    counters: Counters
    def __init__(self, type: _Optional[_Union[EventType, str]] = ..., uptime_s: _Optional[int] = ..., wifi_rssi_dbm: _Optional[int] = ..., device_info: _Optional[_Union[_device_info_pb2.DeviceInfo, _Mapping]] = ..., counters: _Optional[_Union[Counters, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: han_port.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'han_port.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ehan_port.proto\x12\x08han_port\"\x87\x13\n\rHanPortSample\x12\"\n\x15timestamp_utc_meter_s\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12 \n\x13timestamp_utc_ntp_s\x18\x1c \x01(\x04H\x01\x88\x01\x01\x12\x32\n%energy_active_delivered_to_client_kwh\x18\x02 \x01(\x02H\x02\x88\x01\x01\x12\x32\n%energy_active_delivered_by_client_kwh\x18\x03 \x01(\x02H\x03\x88\x01\x01\x12\x36\n)energy_reactive_delivered_to_client_kvarh\x18\x04 \x01(\x02H\x04\x88\x01\x01\x12\x36\n)energy_reactive_delivered_by_client_kvarh\x18\x05 \x01(\x02H\x05\x88\x01\x01\x12\x30\n#power_active_delivered_to_client_kw\x18\x06 \x01(\x02H\x06\x88\x01\x01\x12\x30\n#power_active_delivered_by_client_kw\x18\x07 \x01(\x02H\x07\x88\x01\x01\x12\x34\n\'power_reactive_delivered_to_client_kvar\x18\x08 \x01(\x02H\x08\x88\x01\x01\x12\x34\n\'power_reactive_delivered_by_client_kvar\x18\t \x01(\x02H\t\x88\x01\x01\x12\x33\n&power_active_l1_delivered_to_client_kw\x18\n \x01(\x02H\n\x88\x01\x01\x12\x33\n&power_active_l1_delivered_by_client_kw\x18\x0b \x01(\x02H\x0b\x88\x01\x01\x12\x33\n&power_active_l2_delivered_to_client_kw\x18\x0c \x01(\x02H\x0c\x88\x01\x01\x12\x33\n&power_active_l2_delivered_by_client_kw\x18\r \x01(\x02H\r\x88\x01\x01\x12\x33\n&power_active_l3_delivered_to_client_kw\x18\x0e \x01(\x02H\x0e\x88\x01\x01\x12\x33\n&power_active_l3_delivered_by_client_kw\x18\x0f \x01(\x02H\x0f\x88\x01\x01\x12\x37\n*power_reactive_l1_delivered_to_client_kvar\x18\x10 \x01(\x02H\x10\x88\x01\x01\x12\x37\n*power_reactive_l1_delivered_by_client_kvar\x18\x11 \x01(\x02H\x11\x88\x01\x01\x12\x37\n*power_reactive_l2_delivered_to_client_kvar\x18\x12 \x01(\x02H\x12\x88\x01\x01\x12\x37\n*power_reactive_l2_delivered_by_client_kvar\x18\x13 \x01(\x02H\x13\x88\x01\x01\x12\x37\n*power_reactive_l3_delivered_to_client_kvar\x18\x14 \x01(\x02H\x14\x88\x01\x01\x12\x37\n*power_reactive_l3_delivered_by_client_kvar\x18\x15 \x01(\x02H\x15\x88\x01\x01\x12\x1f\n\x12phase_voltage_l1_v\x18\x16 \x01(\x02H\x16\x88\x01\x01\x12\x1f\n\x12phase_voltage_l2_v\x18\x17 \x01(\x02H\x17\x88\x01\x01\x12\x1f\n\x12phase_voltage_l3_v\x18\x18 \x01(\x02H\x18\x88\x01\x01\x12\x1f\n\x12phase_current_l1_a\x18\x19 \x01(\x02H\x19\x88\x01\x01\x12\x1f\n\x12phase_current_l2_a\x18\x1a \x01(\x02H\x1a\x88\x01\x01\x12\x1f\n\x12phase_current_l3_a\x18\x1b \x01(\x02H\x1b\x88\x01\x01\x42\x18\n\x16_timestamp_utc_meter_sB\x16\n\x14_timestamp_utc_ntp_sB(\n&_energy_active_delivered_to_client_kwhB(\n&_energy_active_delivered_by_client_kwhB,\n*_energy_reactive_delivered_to_client_kvarhB,\n*_energy_reactive_delivered_by_client_kvarhB&\n$_power_active_delivered_to_client_kwB&\n$_power_active_delivered_by_client_kwB*\n(_power_reactive_delivered_to_client_kvarB*\n(_power_reactive_delivered_by_client_kvarB)\n\'_power_active_l1_delivered_to_client_kwB)\n\'_power_active_l1_delivered_by_client_kwB)\n\'_power_active_l2_delivered_to_client_kwB)\n\'_power_active_l2_delivered_by_client_kwB)\n\'_power_active_l3_delivered_to_client_kwB)\n\'_power_active_l3_delivered_by_client_kwB-\n+_power_reactive_l1_delivered_to_client_kvarB-\n+_power_reactive_l1_delivered_by_client_kvarB-\n+_power_reactive_l2_delivered_to_client_kvarB-\n+_power_reactive_l2_delivered_by_client_kvarB-\n+_power_reactive_l3_delivered_to_client_kvarB-\n+_power_reactive_l3_delivered_by_client_kvarB\x15\n\x13_phase_voltage_l1_vB\x15\n\x13_phase_voltage_l2_vB\x15\n\x13_phase_voltage_l3_vB\x15\n\x13_phase_current_l1_aB\x15\n\x13_phase_current_l2_aB\x15\n\x13_phase_current_l3_ab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'han_port_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HANPORTSAMPLE']._serialized_start=29
  _globals['_HANPORTSAMPLE']._serialized_end=2468
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class HanPortSample(_message.Message):
    __slots__ = ("timestamp_utc_meter_s", "timestamp_utc_ntp_s", "energy_active_delivered_to_client_kwh", "energy_active_delivered_by_client_kwh", "energy_reactive_delivered_to_client_kvarh", "energy_reactive_delivered_by_client_kvarh", "power_active_delivered_to_client_kw", "power_active_delivered_by_client_kw", "power_reactive_delivered_to_client_kvar", "power_reactive_delivered_by_client_kvar", "power_active_l1_delivered_to_client_kw", "power_active_l1_delivered_by_client_kw", "power_active_l2_delivered_to_client_kw", "power_active_l2_delivered_by_client_kw", "power_active_l3_delivered_to_client_kw", "power_active_l3_delivered_by_client_kw", "power_reactive_l1_delivered_to_client_kvar", "power_reactive_l1_delivered_by_client_kvar", "power_reactive_l2_delivered_to_client_kvar", "power_reactive_l2_delivered_by_client_kvar", "power_reactive_l3_delivered_to_client_kvar", "power_reactive_l3_delivered_by_client_kvar", "phase_voltage_l1_v", "phase_voltage_l2_v", "phase_voltage_l3_v", "phase_current_l1_a", "phase_current_l2_a", "phase_current_l3_a")
    TIMESTAMP_UTC_METER_S_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_UTC_NTP_S_FIELD_NUMBER: _ClassVar[int]
    ENERGY_ACTIVE_DELIVERED_TO_CLIENT_KWH_FIELD_NUMBER: _ClassVar[int]
    ENERGY_ACTIVE_DELIVERED_BY_CLIENT_KWH_FIELD_NUMBER: _ClassVar[int]
    ENERGY_REACTIVE_DELIVERED_TO_CLIENT_KVARH_FIELD_NUMBER: _ClassVar[int]
    ENERGY_REACTIVE_DELIVERED_BY_CLIENT_KVARH_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_DELIVERED_TO_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_DELIVERED_BY_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_DELIVERED_TO_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_DELIVERED_BY_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_L1_DELIVERED_TO_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_L1_DELIVERED_BY_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_L2_DELIVERED_TO_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_L2_DELIVERED_BY_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_L3_DELIVERED_TO_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_ACTIVE_L3_DELIVERED_BY_CLIENT_KW_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_L1_DELIVERED_TO_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_L1_DELIVERED_BY_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_L2_DELIVERED_TO_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_L2_DELIVERED_BY_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_L3_DELIVERED_TO_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    POWER_REACTIVE_L3_DELIVERED_BY_CLIENT_KVAR_FIELD_NUMBER: _ClassVar[int]
    PHASE_VOLTAGE_L1_V_FIELD_NUMBER: _ClassVar[int]
    PHASE_VOLTAGE_L2_V_FIELD_NUMBER: _ClassVar[int]
    PHASE_VOLTAGE_L3_V_FIELD_NUMBER: _ClassVar[int]
    PHASE_CURRENT_L1_A_FIELD_NUMBER: _ClassVar[int]
    PHASE_CURRENT_L2_A_FIELD_NUMBER: _ClassVar[int]
    PHASE_CURRENT_L3_A_FIELD_NUMBER: _ClassVar[int]
    timestamp_utc_meter_s: int
    timestamp_utc_ntp_s: int
    energy_active_delivered_to_client_kwh: float
    energy_active_delivered_by_client_kwh: float
    energy_reactive_delivered_to_client_kvarh: float
    energy_reactive_delivered_by_client_kvarh: float
    power_active_delivered_to_client_kw: float
    power_active_delivered_by_client_kw: float
    power_reactive_delivered_to_client_kvar: float
    power_reactive_delivered_by_client_kvar: float
    power_active_l1_delivered_to_client_kw: float
    power_active_l1_delivered_by_client_kw: float
    power_active_l2_delivered_to_client_kw: float
    power_active_l2_delivered_by_client_kw: float
    power_active_l3_delivered_to_client_kw: float
    power_active_l3_delivered_by_client_kw: float
    power_reactive_l1_delivered_to_client_kvar: float
    power_reactive_l1_delivered_by_client_kvar: float
    power_reactive_l2_delivered_to_client_kvar: float
    power_reactive_l2_delivered_by_client_kvar: float
    power_reactive_l3_delivered_to_client_kvar: float
    power_reactive_l3_delivered_by_client_kvar: float
    phase_voltage_l1_v: float
    phase_voltage_l2_v: float
    phase_voltage_l3_v: float
    phase_current_l1_a: float
    phase_current_l2_a: float
    phase_current_l3_a: float
    def __init__(self, timestamp_utc_meter_s: _Optional[int] = ..., timestamp_utc_ntp_s: _Optional[int] = ..., energy_active_delivered_to_client_kwh: _Optional[float] = ..., energy_active_delivered_by_client_kwh: _Optional[float] = ..., energy_reactive_delivered_to_client_kvarh: _Optional[float] = ..., energy_reactive_delivered_by_client_kvarh: _Optional[float] = ..., power_active_delivered_to_client_kw: _Optional[float] = ..., power_active_delivered_by_client_kw: _Optional[float] = ..., power_reactive_delivered_to_client_kvar: _Optional[float] = ..., power_reactive_delivered_by_client_kvar: _Optional[float] = ..., power_active_l1_delivered_to_client_kw: _Optional[float] = ..., power_active_l1_delivered_by_client_kw: _Optional[float] = ..., power_active_l2_delivered_to_client_kw: _Optional[float] = ..., power_active_l2_delivered_by_client_kw: _Optional[float] = ..., power_active_l3_delivered_to_client_kw: _Optional[float] = ..., power_active_l3_delivered_by_client_kw: _Optional[float] = ..., power_reactive_l1_delivered_to_client_kvar: _Optional[float] = ..., power_reactive_l1_delivered_by_client_kvar: _Optional[float] = ..., power_reactive_l2_delivered_to_client_kvar: _Optional[float] = ..., power_reactive_l2_delivered_by_client_kvar: _Optional[float] = ..., power_reactive_l3_delivered_to_client_kvar: _Optional[float] = ..., power_reactive_l3_delivered_by_client_kvar: _Optional[float] = ..., phase_voltage_l1_v: _Optional[float] = ..., phase_voltage_l2_v: _Optional[float] = ..., phase_voltage_l3_v: _Optional[float] = ..., phase_current_l1_a: _Optional[float] = ..., phase_current_l2_a: _Optional[float] = ..., phase_current_l3_a: _Optional[float] = ...) -> None: ...



import han_port_pb2 as _han_port_pb2
import device_info_pb2 as _device_info_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TYPE_UNSPECIFIED: _ClassVar[EventType]
    EVENT_TYPE_TIMER: _ClassVar[EventType]
    EVENT_TYPE_PROVISIONING_REQUESTED: _ClassVar[EventType]
    EVENT_TYPE_MQTT_CONNECTED: _ClassVar[EventType]
    EVENT_TYPE_REBOOT_REQUESTED: _ClassVar[EventType]
    EVENT_TYPE_BOOT_UNKNOWN: _ClassVar[EventType]
    EVENT_TYPE_BOOT_SOFTWARE: _ClassVar[EventType]
    EVENT_TYPE_BOOT_POWER_ON: _ClassVar[EventType]
    EVENT_TYPE_BOOT_WATCHDOG: _ClassVar[EventType]
EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_TIMER: EventType
EVENT_TYPE_PROVISIONING_REQUESTED: EventType
EVENT_TYPE_MQTT_CONNECTED: EventType
EVENT_TYPE_REBOOT_REQUESTED: EventType
EVENT_TYPE_BOOT_UNKNOWN: EventType
EVENT_TYPE_BOOT_SOFTWARE: EventType
EVENT_TYPE_BOOT_POWER_ON: EventType
EVENT_TYPE_BOOT_WATCHDOG: EventType

class Diagnostic(_message.Message):
    __slots__ = ("type", "uptime_s", "wifi_rssi_dbm", "device_info", "han_msg_successfully_parsed", "han_msg_buffer_overflow")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UPTIME_S_FIELD_NUMBER: _ClassVar[int]
    WIFI_RSSI_DBM_FIELD_NUMBER: _ClassVar[int]
    DEVICE_INFO_FIELD_NUMBER: _ClassVar[int]
    HAN_MSG_SUCCESSFULLY_PARSED_FIELD_NUMBER: _ClassVar[int]
    HAN_MSG_BUFFER_OVERFLOW_FIELD_NUMBER: _ClassVar[int]
    type: EventType
    uptime_s: int
    wifi_rssi_dbm: int
    device_info: _device_info_pb2.DeviceInfo
    han_msg_successfully_parsed: int
    han_msg_buffer_overflow: int
    def __init__(self, type: _Optional[_Union[EventType, str]] = ..., uptime_s: _Optional[int] = ..., wifi_rssi_dbm: _Optional[int] = ..., device_info: _Optional[_Union[_device_info_pb2.DeviceInfo, _Mapping]] = ..., han_msg_successfully_parsed: _Optional[int] = ..., han_msg_buffer_overflow: _Optional[int] = ...) -> None: ...

class Payload(_message.Message):
    __slots__ = ("sample", "diagnostic")
    SAMPLE_FIELD_NUMBER: _ClassVar[int]
    DIAGNOSTIC_FIELD_NUMBER: _ClassVar[int]
    sample: _han_port_pb2.HanPortSample
    diagnostic: Diagnostic
    def __init__(self, sample: _Optional[_Union[_han_port_pb2.HanPortSample, _Mapping]] = ..., diagnostic: _Optional[_Union[Diagnostic, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device_info.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device_info.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x65vice_info.proto\x12\x0b\x64\x65vice_info\"^\n\nDeviceInfo\x12\x13\n\x0bmac_address\x18\x01 \x01(\x0c\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x12\n\nsw_version\x18\x03 \x01(\t\x12\x13\n\x0bhw_revision\x18\x04 \x01(\rB;\n7io.bitvis.power.interfaces.powerhub.deviceinfo.protobufP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.bitvis.power.interfaces.powerhub.deviceinfo.protobufP\001'
  _globals['_DEVICEINFO']._serialized_start=34
  _globals['_DEVICEINFO']._serialized_end=128
# @@protoc_insertion_point(module_scope)



"""Bitvis Power Hub protobuf definitions."""

from __future__ import annotations

__version__ = "0.1.0"

# Re-export generated protobuf modules for convenience
from . import device_info_pb2, diagnostic_pb2, han_port_pb2, powerhub_pb2

__all__ = [
    "device_info_pb2",
    "diagnostic_pb2",
    "han_port_pb2",
    "powerhub_pb2",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerhub.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerhub.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import han_port_pb2 as han__port__pb2
from . import device_info_pb2 as device__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0epowerhub.proto\x12\x08powerhub\x1a\x0ehan_port.proto\x1a\x11\x64\x65vice_info.proto\"\xcc\x01\n\nDiagnostic\x12!\n\x04type\x18\x01 \x01(\x0e\x32\x13.powerhub.EventType\x12\x10\n\x08uptime_s\x18\x02 \x01(\x04\x12\x15\n\rwifi_rssi_dbm\x18\x03 \x01(\x05\x12,\n\x0b\x64\x65vice_info\x18\x04 \x01(\x0b\x32\x17.device_info.DeviceInfo\x12#\n\x1bhan_msg_successfully_parsed\x18\x05 \x01(\r\x12\x1f\n\x17han_msg_buffer_overflow\x18\x06 \x01(\r\"k\n\x07Payload\x12)\n\x06sample\x18\x01 \x01(\x0b\x32\x17.han_port.HanPortSampleH\x00\x12*\n\ndiagnostic\x18\x02 \x01(\x0b\x32\x14.powerhub.DiagnosticH\x00\x42\t\n\x07payload*\x9b\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45VENT_TYPE_TIMER\x10\x01\x12%\n!EVENT_TYPE_PROVISIONING_REQUESTED\x10\x02\x12\x1d\n\x19\x45VENT_TYPE_MQTT_CONNECTED\x10\x03\x12\x1f\n\x1b\x45VENT_TYPE_REBOOT_REQUESTED\x10\x04\x12\x1b\n\x17\x45VENT_TYPE_BOOT_UNKNOWN\x10\x05\x12\x1c\n\x18\x45VENT_TYPE_BOOT_SOFTWARE\x10\x06\x12\x1c\n\x18\x45VENT_TYPE_BOOT_POWER_ON\x10\x07\x12\x1c\n\x18\x45VENT_TYPE_BOOT_WATCHDOG\x10\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerhub_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EVENTTYPE']._serialized_start=380
  _globals['_EVENTTYPE']._serialized_end=663
  _globals['_DIAGNOSTIC']._serialized_start=64
  _globals['_DIAGNOSTIC']._serialized_end=268
  _globals['_PAYLOAD']._serialized_start=270
  _globals['_PAYLOAD']._serialized_end=377
# @@protoc_insertion_point(module_scope)
